# -*- coding: utf-8 -*-
"""
Created on Wed May 30 15:27:17 2018

@author: martindrech
"""

from __future__ import absolute_import, division, print_function

daqfound = True

try:
    from mcculw import ul
    from mcculw.enums import DigitalIODirection, ULRange
    from examples.props.digital import DigitalProps
    from examples.props.ao import AnalogOutputProps

    from mcculw.ul import ULError

    ao_range = ULRange.BIP10VOLTS

except:
    print('import error: mcculw not installed. In linux this might not be available. ')
    daqfound = False
#%%
        
class daq_DO(object):
    def __init__(self, out_num):
        global daqfound
        
        self.board_num = 0
        self.out_num = out_num
        if daqfound:
            self.digital_props = DigitalProps(self.board_num)
    
            # Find the first port that supports output, defaulting to None
            # if one is not found.
            self.port = next(
                (port for port in self.digital_props.port_info
                 if port.supports_output), None)
    
            # If the port is configurable, configure it for output
            if self.port != None and self.port.is_port_configurable:
                try:
                    ul.d_config_port(
                        self.board_num, self.port.type, DigitalIODirection.OUT)
                except ULError as e:
                    self.show_ul_error(e)
            
    if daqfound:
        def set_out(self, bit_value):
            try:
                # Output the value to the board
                ul.d_bit_out(self.board_num, self.port.type, self.out_num, bit_value)
            except ULError as e:
                self.show_ul_error(e)
    else:
        def set_out(self, bit_value):
            print('Digital out %i set to %s' % (self.out_num, bit_value) )
            return bit_value, self.out_num
                       
        
class daq_AO(object):
    def __init__(self, out_num):
        global daqfound
        self.board_num = 0
        self.out_num = out_num
        if daqfound:
            self.ao_props = AnalogOutputProps(self.board_num)
    if daqfound:
        def set_out(self, value):
            try:
                ul.v_out(self.board_num, self.out_num, ao_range, value)
            except ULError as e:
                self.show_ul_error(e)
            
            
        def get_analog_out(self):
            #ao_range = self.ao_props.available_ranges[0]
            try: 
                state = ul.a_in(self.board_num, self.out_num, ao_range)
                print(state)
            except ValueError:
                return 0
    else:
        def set_out(self, value):
            print('Analog out %i set to %f' % (self.out_num, value) )
            return value, self.out_num
######################################################################################
